pub struct WeakNode<T: Debug + Clone> {
pub inner: Weak<HedelCell<NodeInner<T>>>,
}Expand description
Rc is a strong pointer meaning it increment a reference counter.
Weak is a weak pointer meaning it doesn’t increment the reference counter,
letting you access the value if it still exists in memory,
modify it as its pointing to HedelCell,
but without holding it in memory any longer.
Necessary to avoid memory leaking.
Fields
inner: Weak<HedelCell<NodeInner<T>>>Implementations